==> Acme-MetaSyntactic-Themes-1.000.tar.gz: Acme-MetaSyntactic-Themes-1.000/lib/Acme/MetaSyntactic/garbage.pm <==
package Acme::MetaSyntactic::garbage;
use strict;
use Acme::MetaSyntactic::Locale;
our @ISA = qw( Acme::MetaSyntactic::Locale );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::garbage - The garbage theme

=head1 DESCRIPTION

Rubbish synonyms to use when testing your smelly modules.

English list taken from L<http://dico.isc.cnrs.fr/dico/en/search>.
French list taken from L<http://dico.isc.cnrs.fr/dico/fr/search>.

=head1 CONTRIBUTOR

Jrme Fenal.

Introduced in Acme-MetaSyntactic version 0.35, published on August 15, 2005.

Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.

=cut

__DATA__
# default
en
# names en
absurdity applesauce balderdash baloney bilge blether boloney bosh bull bullshit
claptrap cobblers debris detritus drivel dross eyewash fake folderol folly food
gadolinium gaff garbage gibber havoc hogwash humbug incongruity junk litter
maiming mess nonsense offal pandemonium refuse rigmarole rubbish rubble scoria
scraps shamble shambles slag slops swill trash tripe trumpery twaddle waffle
wander waste wish_wash wreckage
# names fr
abjection abomination alluvion avarice balayure bas_fond bassesse battitures
bauge bois boue boueux bouillasse bourbe bourbier bourre bourrier braye bris
brouillasse bruine caca camelote canaillerie charnier charogne chiure chute
cloaque cochon cochonnerie compost corruption crasse crevure crotte curure
debauche debris decharge dechet deperdition depot detritus eclaboussure eclat
ecume egout engrais entourloupette epais epave epluchure excrement fagne fange
ferraille fiente freinte fumier gabegie gachis gadoue gadouille gravelure
gringuenaude grivoiserie grossier grossierete gueuserie ignorance immondice
impurete incongruite indelicatesse inexcusable infamie injure laideur lavure lie
limon lourd macule malproprete marais marecage margouillis mechancete merde
merdier misere mortier mouise mouton nettoyure noirceur nul obscenite ordure
pacotille parcelle patine patraque perfidie perte petitesse pise poison
poudrette pouillerie pourriture poussiere propos pus raclure ramas rebut
recrement relief reliquat residu rincure rogaton rognure rosserie rossignol
ruine ruisseau sabot salaud salete salissure salope saloperie sanie scorie
sediment sentine sordidite souillure stupre tache tare terreau toc tour tourbe
trivialite truand turpitude vacherie vase vaurien vermine vice vidange
vidure vilenie voirie vouerie water_closets

==> Acme-MetaSyntactic-Themes-1.006.tar.gz: Acme-MetaSyntactic-Themes-1.006/lib/Acme/MetaSyntactic/garbage.pm <==
package Acme::MetaSyntactic::garbage;
use strict;
use Acme::MetaSyntactic::Locale;
our @ISA = qw( Acme::MetaSyntactic::Locale );
our $VERSION = '1.001';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::garbage - The garbage theme

=head1 DESCRIPTION

Rubbish synonyms to use when testing your smelly modules.

English list taken from L<http://dico.isc.cnrs.fr/dico/en/search>.
French list taken from L<http://dico.isc.cnrs.fr/dico/fr/search>.

=head1 CONTRIBUTOR

Jrme Fenal.

Introduced in Acme-MetaSyntactic version 0.35, published on August 15, 2005.

Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

Updated with an C<=encoding> pod command in version 1.001,
published on May 14,2012

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.

=cut

__DATA__
# default
en
# names en
absurdity applesauce balderdash baloney bilge blether boloney bosh bull bullshit
claptrap cobblers debris detritus drivel dross eyewash fake folderol folly food
gadolinium gaff garbage gibber havoc hogwash humbug incongruity junk litter
maiming mess nonsense offal pandemonium refuse rigmarole rubbish rubble scoria
scraps shamble shambles slag slops swill trash tripe trumpery twaddle waffle
wander waste wish_wash wreckage
# names fr
abjection abomination alluvion avarice balayure bas_fond bassesse battitures
bauge bois boue boueux bouillasse bourbe bourbier bourre bourrier braye bris
brouillasse bruine caca camelote canaillerie charnier charogne chiure chute
cloaque cochon cochonnerie compost corruption crasse crevure crotte curure
debauche debris decharge dechet deperdition depot detritus eclaboussure eclat
ecume egout engrais entourloupette epais epave epluchure excrement fagne fange
ferraille fiente freinte fumier gabegie gachis gadoue gadouille gravelure
gringuenaude grivoiserie grossier grossierete gueuserie ignorance immondice
impurete incongruite indelicatesse inexcusable infamie injure laideur lavure lie
limon lourd macule malproprete marais marecage margouillis mechancete merde
merdier misere mortier mouise mouton nettoyure noirceur nul obscenite ordure
pacotille parcelle patine patraque perfidie perte petitesse pise poison
poudrette pouillerie pourriture poussiere propos pus raclure ramas rebut
recrement relief reliquat residu rincure rogaton rognure rosserie rossignol
ruine ruisseau sabot salaud salete salissure salope saloperie sanie scorie
sediment sentine sordidite souillure stupre tache tare terreau toc tour tourbe
trivialite truand turpitude vacherie vase vaurien vermine vice vidange
vidure vilenie voirie vouerie water_closets
